@@ -3,7 +3,7 @@ use Moose;
 
 use Bread::Board::Types;
 
-our $VERSION   = '0.08';
+our $VERSION   = '0.09';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'Bread::Board::Service::WithClass',
@@ -12,7 +12,12 @@ with 'Bread::Board::Service::WithClass',
 
 sub get {
     my $self = shift;
-    $self->class->new( %{ $self->params } );
+
+    my $constructor = eval { $self->class->meta->constructor_name };
+
+    $constructor ||= 'new';
+
+    $self->class->$constructor( %{ $self->params } );
 }
 
 __PACKAGE__->meta->make_immutable;
